@@ -3,13 +3,13 @@
 # You should not use this R-script on its own!
 #
 # Have fun with the CM SAF R TOOLBOX!
-#                                              (Steffen Kothe / CM SAF 2019-08-08)
+#                                              (Steffen Kothe / CM SAF 2020-07-24)
 #__________________________________________________________________________________
 
 descriptionString <-
   "
 
-The CM SAF R TOOLBOX 2.0.1 -- 'Don`t Panic'
+The CM SAF R TOOLBOX 3.0.0 -- 'Share and Enjoy'
 
 The intention of the CM SAF R Toolbox is to help you using
 CM SAF NetCDF formatted data
@@ -25,7 +25,7 @@ right in and analyze or visualize a .nc file.
 Suggestions for improvements and praise for the developers
 can be sent to contact.cmsaf@dwd.de.
 
-- Steffen Kothe - 2019-08-08 -"
+- Steffen Kothe - 2020-07-24 -"
 
 # Variable can be found in global.R
 if (isRunningLocally) {
@@ -109,11 +109,12 @@ fluidPage(
                                     uiOutput("prepareString"),
                                     br(),
                                     shinyjs::hidden(actionButton("tarFileLocal",
-                                                                 label = "Browse files...")),
-                                    shinyjs::hidden(fileInput(inputId = "tarFileRemote",
-                                                              label = "Browse files...",
+                                                                 label = "Choose a file...")),
+                                    shinyjs::hidden(shinyFiles::shinyFilesButton(
+                                                              id = "tarFileRemote",
+                                                              label = "Choose a file...",
                                                               multiple = FALSE,
-                                                              accept = c("application/x-tar", ".tar"))))),
+                                                              title = "Please select a .tar-file.")))),
                          shinyjs::hidden(
                            tags$div(id = "panel_prepareInput1",
                                     uiOutput("dateRange_ui"),
@@ -174,10 +175,11 @@ fluidPage(
                                              shinyjs::hidden(h5(id = "or_analyze", "or")),
                                              shinyjs::hidden(actionButton("ncFileLocal_analyze",
                                                                           label = "Choose a file...")),
-                                             shinyjs::hidden(fileInput(inputId = "ncFileRemote_analyze",
-                                                                       label = "Choose a file...",
-                                                                       multiple = FALSE,
-                                                                       accept = c(".nc")))))),
+                                             shinyjs::hidden(shinyFiles::shinyFilesButton(
+                                                              id = "ncFileRemote_analyze",
+                                                              label = "Choose a file...",
+                                                              multiple = FALSE,
+                                                              title = "Please select a .nc-file."))))),
                          shinyjs::hidden(
                            tags$div(id = "panel_analyze",
                                     fluidRow(
@@ -190,10 +192,20 @@ fluidPage(
                                                          width = "320px"),
                                              uiOutput("operator"),
                                              # Operator options
+                                             shinyjs::hidden(checkboxInput("accumulateInfile",
+                                                                           "Do you want to accumulate the infile over time?",
+                                                                           value = TRUE)),
+                                             shinyjs::hidden(checkboxInput("attachToExisting",
+                                                                           "Do you want to attach the data to that of an already existing file?"
+                                                                           )),
+                                             shinyjs::hidden(tags$div(id = "attach_warning",
+                                                                      "Warning: Only use this option if you are sure that the spatial and temporal coverage are correct."
+                                                                      )),
                                              shinyjs::hidden(numericInput("constant",
                                                                           "Enter a number",
                                                                           value = 1,
                                                                           width = "320px")),
+                                             shinyjs::hidden(uiOutput("select_country")),
                                              shinyjs::hidden(uiOutput("region_to_select")),
                                              shinyjs::hidden(tags$div(id = "point",
                                                                       numericInput("latPoint",
@@ -202,7 +214,12 @@ fluidPage(
                                                                       numericInput("lonPoint",
                                                                                    "Select longitude point",
                                                                                    value = 0))),
+                                             shinyjs::hidden(tableOutput("chosen_points")),
+                                             shinyjs::hidden(actionButton("add_point", "Add Point")),
+                                             shinyjs::hidden(uiOutput("multi_warning")),
+                                             shinyjs::hidden(uiOutput("points_to_select")),
                                              shinyjs::hidden(uiOutput("dateRange_to_select")),
+                                             shinyjs::hidden(uiOutput("climatology_years")),
                                              shinyjs::hidden(checkboxInput("useFastTrend",
                                                                            "Do you want to use fast computation (memory consuming)",
                                                                            value = TRUE)),
@@ -219,28 +236,47 @@ fluidPage(
                                                                                   "July", "August", "September", "October", "November", "December"),
                                                                                 width = "320px")),
                                              shinyjs::hidden(uiOutput("years_to_select")),
-                                             shinyjs::hidden(checkboxGroupInput("times",
-                                                                                "Please select time points",
-                                                                                c("00:00:00","00:01:00","00:02:00","00:03:00","00:04:00","00:05:00",
-                                                                                  "00:06:00","00:07:00","00:08:00","00:09:00","00:10:00","00:11:00",
-                                                                                  "00:12:00","00:13:00","00:14:00","00:15:00","00:16:00","00:17:00",
-                                                                                  "00:18:00","00:19:00","00:20:00","00:21:00","00:22:00","00:23:00"),
-                                                                                width = "320px")),
+                                             shinyjs::hidden(uiOutput("times_to_select")),
                                              shinyjs::hidden(selectInput("method",
                                                                          "Select regridding method",
                                                                          choices = c("Nearest Neighbour interpolation" = "nearest",
                                                                                      "Bilinear Interpolation" = "bilinear",
                                                                                      "Conservative remapping" = "conservative"),
                                                                          width = "320px")),
+                                             shinyjs::hidden(tags$div(id = "twofiles",
+                                                                      shinyFiles::shinyFilesButton("ncSecondFileRemote",
+                                                                                                   "Choose second file",
+                                                                                                   "The chosen operator requires a second nc infile.",
+                                                                                                   FALSE),
+                                                                      verbatimTextOutput("secondFile"))),
+                                             shinyjs::hidden(selectInput("plot_format",
+                                                                        "Select plot format",
+                                                                        choices = c("graphic", "animation"))),
+                                             shinyjs::hidden(tags$div(id = "multiDayNonAccuGraphic",
+                                                                      "Creating a multi day graphic of non accumulated data is not possible. Please choose to accumulate the infile, or plot format 'animation', or select a single day in the date range")),
+                                             conditionalPanel(condition = "input.plot_format == 'animation'",
+                                                              numericInput("animation_pace",
+                                                                           "Select animation pace",
+                                                                           value = 0.07,
+                                                                           min = 0.01,
+                                                                           max = 100000,
+                                                                           step = 0.1)),
                                              selectInput("format",
                                                          "Select output format",
                                                          choices = c("NetCDF4" = 4, "NetCDF3" = 3),
                                                          width = "320px"),
-                                             checkboxInput("applyAnother",
-                                                           "Do you want to apply another operator afterwards?"),
-                                             checkboxInput("instantlyVisualize",
-                                                           "Do you want to visualize the results right away?",
-                                                           value = TRUE),
+                                             tags$div(
+                                               id = "applyAnotherOrVisualize",
+                                               checkboxInput("applyAnother",
+                                                             "Do you want to apply another operator afterwards?"),
+                                               checkboxInput("instantlyVisualize",
+                                                             "Do you want to visualize the results right away?",
+                                                             value = TRUE)),
+                                             shinyjs::hidden(
+                                               tags$div(
+                                                 id = "ClimateAnalysisMessage",
+                                                 "Climate Analysis operators will result in instant visualization.")
+                                             ),
                                              h5("Hint: You can start with a new input file by clicking on 'Analyze'."),
                                              actionButton("applyOperator",
                                                           label = "Apply operator",
@@ -275,10 +311,11 @@ fluidPage(
                                              shinyjs::hidden(h5(id = "or_visualize", "or")),
                                              shinyjs::hidden(actionButton("ncFileLocal_visualize",
                                                                           label = "Choose a file...")),
-                                             shinyjs::hidden(fileInput(inputId = "ncFileRemote_visualize",
-                                                                       label = "Choose a file...",
-                                                                       multiple = FALSE,
-                                                                       accept = c(".nc"))))),
+                                             shinyjs::hidden(shinyFiles::shinyFilesButton(
+                                                              id = "ncFileRemote_visualize",
+                                                              label = "Choose a file...",
+                                                              multiple = FALSE,
+                                                              title = "Please select a .nc-file.")))),
                            shinyjs::hidden(tags$div(id = "spinner_visualize",
                                                     class = "spinner",
                                                     tags$div(class = "spinner-title", h4("Preparing your plot...")),
@@ -295,7 +332,6 @@ fluidPage(
                    tags$div(id = "sidebar_2d_plot",
                             uiOutput("timestep_visualize"),
                             conditionalPanel(condition = "input.proj == 'rect'",
-                                             checkboxInput("show_zoom", "Show Zoom"),
                                              checkboxInput("plot_region", "Plot region"),
                                              conditionalPanel(condition = "input.plot_region",
                                                               # All countries can be found in global.R
@@ -303,13 +339,15 @@ fluidPage(
                                                                        column(6, uiOutput("region_options"))),
                                                               shinyjs::hidden(actionButton("shapefileLocal",
                                                                                            label = "Choose a shape file...")),
-                                                              shinyjs::hidden(fileInput(inputId = "shapefileRemote",
+                                                              shinyjs::hidden(shinyFiles::shinyFilesButton(
+                                                                                        id = "shapefileRemote",
                                                                                         label = "Choose a shape file...",
                                                                                         multiple = FALSE,
-                                                                                        accept = c(".shp")))),
+                                                                                        title = "Please select a .shp-file."))),
                                              conditionalPanel(condition = "input.plot_region",
                                                               br()),
                                              conditionalPanel(condition = "!input.plot_region",
+                                                              checkboxInput("show_zoom", "Show Zoom"),
                                                               uiOutput("lon_visualize"),
                                                               uiOutput("lat_visualize"))),
                             conditionalPanel(condition = "input.proj == 'ortho'",
@@ -349,27 +387,27 @@ fluidPage(
                                                           min = 2,
                                                           max = 64,
                                                           step = 1)))),
-                                             selectizeInput("PAL", label = "Colorbar",
+                                             selectizeInput("PAL",
+                                                            label = "Colorbar",
                                                             choices = list(),
                                                             options = list(create = TRUE,
                                                                            render = I(renderString))),
-                                             checkboxInput("reverse", "Reverse", value = FALSE, width = NULL),
+                                             checkboxInput("reverse", "Reverse Colors", value = FALSE, width = NULL),
                             conditionalPanel(condition = "input.proj == 'rect' || input.plot_region",
                                              fluidRow(column(6,
                                                              uiOutput("num_rmin")),
                                                       column(6,
                                                              uiOutput("num_rmax")))),
                             conditionalPanel(condition = "!input.plot_region",
-                                             checkboxInput("int","Plot Country Borders"),
-                                             checkboxInput("plot_rinstat","Plot R-Instat"),
+                                             checkboxInput("int", "Plot Country Borders"),
+                                             checkboxInput("plot_rinstat", "Plot R-Instat"),
                                              shinyjs::hidden(actionButton("instat_file_local",
                                                                           label = "Browse files...")),
-
-
-                                             shinyjs::hidden(fileInput(inputId = "instat_file_remote",
-                                                                       label = "Browse files...",
-                                                                       multiple = FALSE,
-                                                                       accept = c(".RData")))),
+                                             shinyjs::hidden(shinyFiles::shinyFilesButton(
+                                                              id = "instat_file_remote",
+                                                              label = "Choose a file...",
+                                                              multiple = FALSE,
+                                                              title = "Please select a .RData-file."))),
                             conditionalPanel(condition = "input.plot_region || input.proj == 'rect'",
                                              checkboxInput("location", "Plot Own Location"),
                                              conditionalPanel(condition = "input.location == true",
@@ -412,40 +450,54 @@ fluidPage(
                                                       palette = "limited",
                                                       returnName = TRUE,
                                                       value = "royalblue4"),
-                            selectInput("checkGroup_type",
-                                        label = "Line Type",
-                                        choices = list("Line" = 1,
-                                                       "Points" = 2,
-                                                       "Line+Points" = 3,
-                                                       "Steps" = 4,
-                                                       "Histogram" = 5),
-                                        selected = 1),
-                            checkboxInput("trend","Add linear trend line"),
-                            checkboxInput("analyze_timeseries","Analyze timeseries"),
-                            numericInput("ticknumber",
-                                         label = "Number of major ticks",
-                                         value = 6,
-                                         min = 2),
-                            selectInput("dateformat",
-                                        label = "Date format",
-                                        choices = list("YYYY" = 1,
-                                                       "YYYY-MM" = 2,
-                                                       "YYYY-MM-DD" = 3),
-                                        selected = 2),
-                            uiOutput("title_text_1d"),
-                            uiOutput("subtitle_text_1d")),
+                            checkboxInput("analyze_timeseries", "Analyze timeseries"),
+                            conditionalPanel(
+                              selectInput("checkGroup_type",
+                                          label = "Line Type",
+                                          choices = list("Line" = 1,
+                                                         "Points" = 2,
+                                                         "Line+Points" = 3,
+                                                         "Steps" = 4,
+                                                         "Histogram" = 5),
+                                          selected = 1),
+                              condition = '!input.analyze_timeseries',
+                              checkboxInput("trend", "Add linear trend line"),
+                              numericInput("ticknumber",
+                                           label = "Number of major ticks",
+                                           value = 6,
+                                           min = 2),
+                              selectInput("dateformat",
+                                          label = "Date format",
+                                          choices = list("YYYY" = 1,
+                                                         "YYYY-MM" = 2,
+                                                         "YYYY-MM-DD" = 3,
+                                                         "YYYY-MM-DD HH:MM" = 4),
+                                          selected = 2),
+                              uiOutput("title_text_1d"),
+                              uiOutput("subtitle_text_1d"))),
 
                    # FOR NOW NOT ALLOWING CHANGES TO WIDTH AND HEIGHT IN APP. (DO IT IN GLOBAL.R)
                    # uiOutput("width_height"),
-                   fluidRow(column(8,
-                                   downloadButton("downloadPlot",
-                                                  "Save plot",
-                                                  style = "width: 100%;")),
-                            column(4,
-                                   actionButton("backToSetup",
-                                                label = "Back",
-                                                class = "exit-button",
-                                                width = "100%")))),
+                   fluidRow(
+                     shinyjs::hidden(
+                       tags$div(
+                         id = "downloadExit",
+                         column(8,
+                                actionButton("showModal", "Download")),
+                         column(4,
+                                actionButton("backToSetup",
+                                             label = "Back",
+                                             class = "exit-button",
+                                             width = "100%")))),
+                     shinyjs::hidden(
+                       tags$div(
+                         id = "downloadExitMonitorClimate",
+                         uiOutput("download_monitor_climate"),
+                         br(),
+                         actionButton("backToSetup2",
+                                      label = "Back",
+                                      class = "exit-button",
+                                      width = "100%"))))),
 
       # Description panel.
       mainPanel(tabsetPanel(id = "mainVisualizeTabset",
@@ -457,7 +509,10 @@ fluidPage(
                                                                                             resetOnNew = TRUE))),
                                               tags$div(id = "myImage",
                                                        shinyjs::hidden(imageOutput("myImage_1d")),
-                                                       shinyjs::hidden(imageOutput("myImage_2d"))),
+                                                       shinyjs::hidden(imageOutput("myImage_2d")),
+                                                       shinyjs::hidden(tags$div(id = "myImage_monitorClimate",
+                                                                                imageOutput("monitorClimate_PNG"),
+                                                                                uiOutput("monitorClimate_MP4")))),
                                               shinyjs::hidden(tags$div(id = "spinner_plot1",
                                                                        h3("Rendering plot..."))))),
                             tabPanel("Statistics",
